@@ -1,6 +1,8 @@
 from markdown.extensions import Extension
 from markdown import markdown
 
+from dh_utils.tei.markdown import TEIPostprocessor
+
 from .divisions import DivisionsPreproc, DivisionMarkProcessor, DivisionMarkTreeproc, TrivialProcessor
 from .line_nums import LineNumsPreproc, NumberedBlocksProcessor
 from .milestones import RE_MIL, MilestoneProcessor
@@ -12,7 +14,6 @@ from .gaps_spaces import (
     RE_SUPPLIED, SuppliedProcessor
 )
 from .foreign import RE_FOREIGN, ForeignProcessor
-from .to_tei import TEIPostprocessor
 from .misc import HetaProcessor, RE_HETA
 from .exceptions import LeidenPlusSyntaxError
 
